From 092d59adff5b2817e02e1026ff9873544bbca474 Mon Sep 17 00:00:00 2001
From: "DHS(OpenERP)" <>
Date: Tue, 10 Aug 2010 17:05:06 +0530
Subject: [PATCH] [REF] Corrections of OpenERP instead of Open ERP
bzr revid: jvo@tinyerp.com-20100810113506-hm4ocvh4rd68dmu2
---
addons/account/__openerp__.py | 2 +-
addons/account/account.py | 6 +++---
addons/account/project/project.py | 2 +-
.../account/report/account_entries_report.py | 2 +-
addons/auction/wizard/auction_lots_cancel.py | 14 +++++++-------
.../wizard/auction_transfer_unsold_object.py | 2 +-
.../wizard/wizard_tech_guide_rst.py | 6 +++---
addons/base_module_record/__openerp__.py | 2 +-
.../wizard/base_module_save.py | 2 +-
.../wizard/base_report_designer_modify.py | 4 ++--
.../wizard/tiny_sxw2rml/tiny_sxw2rml.py | 2 +-
addons/crm/__openerp__.py | 8 ++++----
addons/crm/crm.py | 4 ++--
addons/delivery/__openerp__.py | 2 +-
addons/document_ftp/__openerp__.py | 4 ++--
addons/document_ics/document_ics.py | 2 +-
.../document_ics/document_ics_config_wizard.py | 2 +-
addons/email_template/__openerp__.py | 2 +-
addons/email_template/email_template.py | 4 ++--
.../email_template/email_template_mailbox.py | 2 +-
addons/event/event.py | 2 +-
addons/l10n_be/__openerp__.py | 2 +-
addons/l10n_chart_uk_minimal/__openerp__.py | 16 ++++++++--------
addons/l10n_fr/__openerp__.py | 2 +-
.../openerp_mailgate/openerp_mailgate.py | 10 +++++-----
addons/mrp/__openerp__.py | 2 +-
addons/mrp/report/price.py | 6 +++---
addons/procurement/procurement.py | 18 +++++++++---------
addons/product/__openerp__.py | 2 +-
.../profile_accounting/profile_accounting.py | 2 +-
addons/project_scrum/report/sprint_burndown.py | 2 +-
addons/project_scrum/report/task_burndown.py | 2 +-
addons/project_timesheet/project_timesheet.py | 2 +-
addons/sale/sale.py | 2 +-
addons/stock/report/stock_by_location.py | 2 +-
addons/stock/report/stock_graph.py | 2 +-
36 files changed, 74 insertions(+), 74 deletions(-)
diff --git a/addons/account/__openerp__.py b/addons/account/__openerp__.py
index b91de72dff6..5ba019b5621 100644
--- a/addons/account/__openerp__.py
+++ b/addons/account/__openerp__.py
@@ -39,7 +39,7 @@
The processes like maintaining of general ledger is done through the defined financial Journals (entry move line or
grouping is maintained through journal) for a particular financial year and for preparation of vouchers there is a
-module named account_vouchers
+module named account_voucher.
""",
'website': 'http://www.openerp.com',
'init_xml': [],
diff --git a/addons/account/account.py b/addons/account/account.py
index 8d7912356a6..b050f43ad4e 100644
--- a/addons/account/account.py
+++ b/addons/account/account.py
@@ -382,7 +382,7 @@ class account_account(osv.osv):
('consolidation', 'Consolidation'),
('closed', 'Closed'),
], 'Internal Type', required=True, help="This type is used to differentiate types with "\
- "special effects in Open ERP: view can not have entries, consolidation are accounts that "\
+ "special effects in OpenERP: view can not have entries, consolidation are accounts that "\
"can have children accounts for multi-company consolidations, payable/receivable are for "\
"partners accounts (for debit/credit computations), closed for depreciated accounts."),
'user_type': fields.many2one('account.account.type', 'Account Type', required=True,
@@ -627,7 +627,7 @@ class account_journal(osv.osv):
'refund_journal': fields.boolean('Refund Journal', help='Fill this if the journal is to be used for refunds of invoices.'),
'type_control_ids': fields.many2many('account.account.type', 'account_journal_type_rel', 'journal_id','type_id', 'Type Controls', domain=[('code','<>','view'), ('code', '<>', 'closed')]),
'account_control_ids': fields.many2many('account.account', 'account_account_type_rel', 'journal_id','account_id', 'Account', domain=[('type','<>','view'), ('type', '<>', 'closed')]),
- 'view_id': fields.many2one('account.journal.view', 'Display Mode', required=True, help="Gives the view used when writing or browsing entries in this journal. The view tells Open ERP which fields should be visible, required or readonly and in which order. You can create your own view for a faster encoding in each journal."),
+ 'view_id': fields.many2one('account.journal.view', 'Display Mode', required=True, help="Gives the view used when writing or browsing entries in this journal. The view tells OpenERP which fields should be visible, required or readonly and in which order. You can create your own view for a faster encoding in each journal."),
'default_credit_account_id': fields.many2one('account.account', 'Default Credit Account', domain="[('type','!=','view')]", help="It acts as a default account for credit amount"),
'default_debit_account_id': fields.many2one('account.account', 'Default Debit Account', domain="[('type','!=','view')]", help="It acts as a default account for debit amount"),
'centralisation': fields.boolean('Centralised counterpart', help="Check this box to determine that each entry of this journal won't create a new counterpart but will share the same counterpart. This is used in fiscal year closing."),
@@ -2155,7 +2155,7 @@ class account_account_template(osv.osv):
('other','Others'),
('closed','Closed'),
], 'Internal Type', required=True,help="This type is used to differentiate types with "\
- "special effects in Open ERP: view can not have entries, consolidation are accounts that "\
+ "special effects in OpenERP: view can not have entries, consolidation are accounts that "\
"can have children accounts for multi-company consolidations, payable/receivable are for "\
"partners accounts (for debit/credit computations), closed for depreciated accounts."),
'user_type': fields.many2one('account.account.type', 'Account Type', required=True,
diff --git a/addons/account/project/project.py b/addons/account/project/project.py
index 7db18c4458c..431d486592b 100644
--- a/addons/account/project/project.py
+++ b/addons/account/project/project.py
@@ -31,7 +31,7 @@ class account_analytic_journal(osv.osv):
'name' : fields.char('Journal name', size=64, required=True),
'code' : fields.char('Journal code', size=8),
'active' : fields.boolean('Active', help="If the active field is set to true, it will allow you to hide the analytic journal without removing it."),
- 'type': fields.selection([('sale','Sale'), ('purchase','Purchase'), ('cash','Cash'), ('general','General'), ('situation','Situation')], 'Type', size=32, required=True, help="Gives the type of the analytic journal. When it needs for a document (eg: an invoice) to create analytic entries, Open ERP will look for a matching journal of the same type."),
+ 'type': fields.selection([('sale','Sale'), ('purchase','Purchase'), ('cash','Cash'), ('general','General'), ('situation','Situation')], 'Type', size=32, required=True, help="Gives the type of the analytic journal. When it needs for a document (eg: an invoice) to create analytic entries, OpenERP will look for a matching journal of the same type."),
'line_ids' : fields.one2many('account.analytic.line', 'journal_id', 'Lines'),
'company_id': fields.many2one('res.company', 'Company', required=True),
}
diff --git a/addons/account/report/account_entries_report.py b/addons/account/report/account_entries_report.py
index 2103eb40e76..05fe51a0da6 100644
--- a/addons/account/report/account_entries_report.py
+++ b/addons/account/report/account_entries_report.py
@@ -62,7 +62,7 @@ class account_entries_report(osv.osv):
('other', 'Others'),
('closed', 'Closed'),
], 'Internal Type', readonly=True, help="This type is used to differentiate types with "\
- "special effects in Open ERP: view can not have entries, consolidation are accounts that "\
+ "special effects in OpenERP: view can not have entries, consolidation are accounts that "\
"can have children accounts for multi-company consolidations, payable/receivable are for "\
"partners accounts (for debit/credit computations), closed for depreciated accounts."),
'company_id': fields.many2one('res.company', 'Company', readonly=True),
diff --git a/addons/auction/wizard/auction_lots_cancel.py b/addons/auction/wizard/auction_lots_cancel.py
index 195323e32d5..3d443a98e15 100644
--- a/addons/auction/wizard/auction_lots_cancel.py
+++ b/addons/auction/wizard/auction_lots_cancel.py
@@ -24,21 +24,21 @@ from osv import fields
class auction_lots_cancel(osv.osv):
'''
- Open ERP Model
+ OpenERP Model
'''
_name = 'auction.lots.cancel'
_description = 'To cancel auction lots.'
-
+
def cancel(self, cr, uid, ids, context=None):
- """
+ """
To cancel the auction lot
-
+
@param self: The object pointer.
@param cr: A database cursor
@param uid: ID of the user currently logged in
- @param ids: List of IDs selected
- @param context: A standard dictionary
- @return:
+ @param ids: List of IDs selected
+ @param context: A standard dictionary
+ @return:
"""
if not context:
context={}
diff --git a/addons/auction/wizard/auction_transfer_unsold_object.py b/addons/auction/wizard/auction_transfer_unsold_object.py
index 3e50a32f598..73095b3433d 100644
--- a/addons/auction/wizard/auction_transfer_unsold_object.py
+++ b/addons/auction/wizard/auction_transfer_unsold_object.py
@@ -24,7 +24,7 @@ from osv import fields
class auction_transfer_unsold_object(osv.osv):
'''
- Open ERP Model
+ OpenERP Model
'''
_name = 'auction.transfer.unsold.object'
_description = 'To transfer unsold objects'
diff --git a/addons/base_module_doc_rst/wizard/wizard_tech_guide_rst.py b/addons/base_module_doc_rst/wizard/wizard_tech_guide_rst.py
index da161ba1917..327367e1d06 100644
--- a/addons/base_module_doc_rst/wizard/wizard_tech_guide_rst.py
+++ b/addons/base_module_doc_rst/wizard/wizard_tech_guide_rst.py
@@ -141,10 +141,10 @@ class RstDoc(object):
" ",
""" """,
"",
- """.. tip:: This module is part of the Open ERP software, the leading Open Source """,
- """ enterprise management system. If you want to discover Open ERP, check our """,
+ """.. tip:: This module is part of the OpenERP software, the leading Open Source """,
+ """ enterprise management system. If you want to discover OpenERP, check our """,
""" `screencasts `_ or download """,
- """ `Open ERP `_ directly.""",
+ """ `OpenERP `_ directly.""",
"",
".. raw:: html",
"",
diff --git a/addons/base_module_record/__openerp__.py b/addons/base_module_record/__openerp__.py
index 22f413924fb..5c6eaa5f712 100644
--- a/addons/base_module_record/__openerp__.py
+++ b/addons/base_module_record/__openerp__.py
@@ -28,7 +28,7 @@
This module allows you to create a new module without any development.
It records all operations on objects during the recording session and
produce a .ZIP module. So you can create your own module directly from
-the Open ERP client.
+the OpenERP client.
This version works for creating and updating existing records. It recomputes
dependencies and links for all types of widgets (many2one, many2many, ...).
diff --git a/addons/base_module_record/wizard/base_module_save.py b/addons/base_module_record/wizard/base_module_save.py
index ea3fdb22979..fdf444d58c1 100644
--- a/addons/base_module_record/wizard/base_module_save.py
+++ b/addons/base_module_record/wizard/base_module_save.py
@@ -160,7 +160,7 @@ def _create_module(self, cr, uid, data, context):
"installable": True
} """ % data['form']
filewrite = {
- '__init__.py':'#\n# Generated by the Open ERP module recorder !\n#\n',
+ '__init__.py':'#\n# Generated by the OpenERP module recorder !\n#\n',
'__terp__.py':_terp,
dname+'_data.xml': res_xml
}
diff --git a/addons/base_report_designer/wizard/base_report_designer_modify.py b/addons/base_report_designer/wizard/base_report_designer_modify.py
index 98d0bf07ed9..1af72086a24 100644
--- a/addons/base_report_designer/wizard/base_report_designer_modify.py
+++ b/addons/base_report_designer/wizard/base_report_designer_modify.py
@@ -45,7 +45,7 @@ did not installed yet, you can find this package on:
This wizard will provide you the .SXW report that you can modify
in OpenOffice. After having modified it, you will be able to reupload
-it to the Open ERP server.
+it to the OpenERP server.
"""},
'operation': {
'string': 'Operation',
@@ -83,7 +83,7 @@ get_form_result = '''
-
+
'''
get_form_fields = {
diff --git a/addons/base_report_designer/wizard/tiny_sxw2rml/tiny_sxw2rml.py b/addons/base_report_designer/wizard/tiny_sxw2rml/tiny_sxw2rml.py
index 7f7a8178ded..c534c5f2c5d 100644
--- a/addons/base_report_designer/wizard/tiny_sxw2rml/tiny_sxw2rml.py
+++ b/addons/base_report_designer/wizard/tiny_sxw2rml/tiny_sxw2rml.py
@@ -22,7 +22,7 @@
##############################################################################
#!/usr/bin/python
"""
-Tiny SXW2RML - The Open ERP's report engine
+Tiny SXW2RML - The OpenERP's report engine
Tiny SXW2RMLis part of the Tiny report project.
Tiny Report is a module that allows you to render high quality PDF document
diff --git a/addons/crm/__openerp__.py b/addons/crm/__openerp__.py
index 16306abfb44..4512892897f 100644
--- a/addons/crm/__openerp__.py
+++ b/addons/crm/__openerp__.py
@@ -24,24 +24,24 @@
'name': 'Customer & Supplier Relationship Management',
'version': '1.0',
'category': 'Generic Modules/CRM & SRM',
- 'description': """The generic Open ERP Customer Relationship Management
+ 'description': """The generic OpenERP Customer Relationship Management
system enables a group of people to intelligently and efficiently manage
leads, opportunities, meeting, phonecall etc.
It manages key tasks such as communication, identification, prioritization,
assignment, resolution and notification.
-Open ERP ensures that all cases are successfully tracked by users, customers and
+OpenERP ensures that all cases are successfully tracked by users, customers and
suppliers. It can automatically send reminders, escalate the request, trigger
specific methods and lots of other actions based on your own enterprise rules.
The greatest thing about this system is that users don't need to do anything
-special. They can just send email to the request tracker. Open ERP will take
+special. They can just send email to the request tracker. OpenERP will take
care of thanking them for their message, automatically routing it to the
appropriate staff, and make sure all future correspondence gets to the right
place.
The CRM module has a email gateway for the synchronisation interface
-between mails and Open ERP.
+between mails and OpenERP.
Create dashboard for CRM that includes:
* My Leads (list)
* Leads by Stage (graph)
diff --git a/addons/crm/crm.py b/addons/crm/crm.py
index 47a3938e1e2..ee182bdfc2f 100644
--- a/addons/crm/crm.py
+++ b/addons/crm/crm.py
@@ -467,7 +467,7 @@ class crm_case_section(osv.osv):
'change_responsible': fields.boolean('Change Responsible', help="Thick this box if you want that on escalation, the responsible of this sale team automatically becomes responsible of the lead/opportunity escaladed"),
'user_id': fields.many2one('res.users', 'Responsible User'),
'member_ids':fields.many2many('res.users', 'sale_member_rel', 'section_id', 'member_id', 'Team Members'),
- 'reply_to': fields.char('Reply-To', size=64, help="The email address put in the 'Reply-To' of all emails sent by Open ERP about cases in this sales team"),
+ 'reply_to': fields.char('Reply-To', size=64, help="The email address put in the 'Reply-To' of all emails sent by OpenERP about cases in this sales team"),
'parent_id': fields.many2one('crm.case.section', 'Parent Team'),
'child_ids': fields.one2many('crm.case.section', 'parent_id', 'Child Teams'),
'resource_calendar_id': fields.many2one('resource.calendar', "Resource's Calendar"),
@@ -673,7 +673,7 @@ class crm_case_section_custom(osv.osv):
'allow_unlink': fields.boolean('Allow Delete', help="Allows to delete non draft cases"),
'sequence': fields.integer('Sequence'),
'user_id': fields.many2one('res.users', 'Responsible User'),
- 'reply_to': fields.char('Reply-To', size=64, help="The email address put in the 'Reply-To' of all emails sent by Open ERP about cases in this section"),
+ 'reply_to': fields.char('Reply-To', size=64, help="The email address put in the 'Reply-To' of all emails sent by OpenERP about cases in this section"),
'parent_id': fields.many2one('crm.case.section.custom', 'Parent Section'),
'note': fields.text('Notes'),
}
diff --git a/addons/delivery/__openerp__.py b/addons/delivery/__openerp__.py
index 191677292f0..193bd0bcaee 100644
--- a/addons/delivery/__openerp__.py
+++ b/addons/delivery/__openerp__.py
@@ -26,7 +26,7 @@
'category': 'Generic Modules/Sales & Purchases',
'description': """Allows you to add delivery methods in sale orders and picking.
You can define your own carrier and delivery grids for prices.
- When creating invoices from picking, Open ERP is able to add and compute the shipping line.
+ When creating invoices from picking, OpenERP is able to add and compute the shipping line.
""",
'author': 'OpenERP SA',
diff --git a/addons/document_ftp/__openerp__.py b/addons/document_ftp/__openerp__.py
index fbae2266215..9be245e36a0 100644
--- a/addons/document_ftp/__openerp__.py
+++ b/addons/document_ftp/__openerp__.py
@@ -25,8 +25,8 @@
'version': '1.99',
'category': 'Generic Modules/Others',
'description': """This is a support FTP Interface with document management system.
- With this module you would not only be able to access documents through open erp
- but you would also be able to connect with them through the file system using the
+ With this module you would not only be able to access documents through OpenERP
+ but you would also be able to connect with them through the file system using the
a FTP client.
""",
'author': 'OpenERP SA',
diff --git a/addons/document_ics/document_ics.py b/addons/document_ics/document_ics.py
index a9c5c90fefb..fdcf9d90e30 100644
--- a/addons/document_ics/document_ics.py
+++ b/addons/document_ics/document_ics.py
@@ -63,7 +63,7 @@ class document_directory_ics_fields(osv.osv):
_name = 'document.directory.ics.fields'
_description = 'Document Directory ICS Fields'
_columns = {
- 'field_id': fields.many2one('ir.model.fields', 'Open ERP Field'),
+ 'field_id': fields.many2one('ir.model.fields', 'OpenERP Field'),
'name': fields.selection(map(lambda x: (x, x), ICS_TAGS.keys()), 'ICS Value', required=True),
'content_id': fields.many2one('document.directory.content', 'Content',\
required=True, ondelete='cascade'),
diff --git a/addons/document_ics/document_ics_config_wizard.py b/addons/document_ics/document_ics_config_wizard.py
index 1e4b73c825d..ca7c9f02eb0 100644
--- a/addons/document_ics/document_ics_config_wizard.py
+++ b/addons/document_ics/document_ics_config_wizard.py
@@ -63,7 +63,7 @@ class document_ics_crm_wizard(osv.osv_memory):
'jobs': fields.boolean('Jobs Hiring Process', help="Helps you to organise the jobs\
hiring process: evaluation, meetings, email integration..."),
'document_ics':fields.boolean('Shared Calendar', help=" Will allow you to synchronise \
- your Open ERP calendars with your phone, outlook, Sunbird, ical, ..."),
+ your OpenERP calendars with your phone, outlook, Sunbird, ical, ..."),
'bugs': fields.boolean('Bug Tracking', help="Used by companies to track bugs and \
support requests on software"),
'helpdesk': fields.boolean('Helpdesk', help="Manages an Helpdesk service."),
diff --git a/addons/email_template/__openerp__.py b/addons/email_template/__openerp__.py
index 917df3dde70..aa3ea2045d2 100644
--- a/addons/email_template/__openerp__.py
+++ b/addons/email_template/__openerp__.py
@@ -21,7 +21,7 @@
##############################################################################
{
- "name" : "Email Template for Open ERP",
+ "name" : "Email Template for OpenERP",
"version" : "0.7 RC",
"author" : "Sharoon Thomas, Openlabs",
"website" : "http://openerp.com",
diff --git a/addons/email_template/email_template.py b/addons/email_template/email_template.py
index cbc03ec1944..fb7c16f69c7 100644
--- a/addons/email_template/email_template.py
+++ b/addons/email_template/email_template.py
@@ -72,7 +72,7 @@ def get_value(cursor, user, recid, message=None, template=None, context=None):
@param recid: ID of the target record under evaluation
@param message: The expression to be evaluated
@param template: BrowseRecord object of the current template
- @param context: Open ERP Context
+ @param context: OpenERP Context
@return: Computed message (unicode) or u""
"""
pool = pooler.get_pool(cursor.dbname)
@@ -683,7 +683,7 @@ class email_template_preview(osv.osv_memory):
Returns the default value for model field
@param cursor: Database Cursor
@param user: ID of current user
- @param context: Open ERP Context
+ @param context: OpenERP Context
"""
return self.pool.get('email.template').read(
cursor,
diff --git a/addons/email_template/email_template_mailbox.py b/addons/email_template/email_template_mailbox.py
index d594a01c087..3348ab4ca2a 100644
--- a/addons/email_template/email_template_mailbox.py
+++ b/addons/email_template/email_template_mailbox.py
@@ -37,7 +37,7 @@ class email_template_mailbox(osv.osv):
def run_mail_scheduler(self, cursor, user, context=None):
"""
- This method is called by Open ERP Scheduler
+ This method is called by OpenERP Scheduler
to periodically send emails
"""
try:
diff --git a/addons/event/event.py b/addons/event/event.py
index bc04927da36..bfc21544061 100644
--- a/addons/event/event.py
+++ b/addons/event/event.py
@@ -200,7 +200,7 @@ class event_event(osv.osv):
'parent_id': fields.many2one('event.event', 'Parent Event', readonly=False, states={'done': [('readonly', True)]}),
'section_id': fields.many2one('crm.case.section', 'Sale Team', readonly=False, states={'done': [('readonly', True)]}),
'child_ids': fields.one2many('event.event', 'parent_id', 'Child Events', readonly=False, states={'done': [('readonly', True)]}),
- 'reply_to': fields.char('Reply-To', size=64, readonly=False, states={'done': [('readonly', True)]}, help="The email address put in the 'Reply-To' of all emails sent by Open ERP"),
+ 'reply_to': fields.char('Reply-To', size=64, readonly=False, states={'done': [('readonly', True)]}, help="The email address put in the 'Reply-To' of all emails sent by OpenERP"),
'type': fields.many2one('event.type', 'Type', help="Type of Event like Seminar, Exhibition, Conference, Training.", readonly=False, states={'done': [('readonly', True)]}),
'register_max': fields.integer('Maximum Registrations', help="Provide Maximun Number of Registrations", readonly=True, states={'draft': [('readonly', False)]}),
'register_min': fields.integer('Minimum Registrations', help="Providee Minimum Number of Registrations", readonly=True, states={'draft': [('readonly', False)]}),
diff --git a/addons/l10n_be/__openerp__.py b/addons/l10n_be/__openerp__.py
index 354ae84f9cd..05de2e74294 100644
--- a/addons/l10n_be/__openerp__.py
+++ b/addons/l10n_be/__openerp__.py
@@ -22,7 +22,7 @@
'version': '1.1',
'category': 'Localisation/Account Charts',
'description': """
- This is the base module to manage the accounting chart for Belgium in Open ERP.
+ This is the base module to manage the accounting chart for Belgium in OpenERP.
After Installing this module,The Configuration wizard for accounting is launched.
* We have the account templates which can be helpful to generate Charts of Accounts.
diff --git a/addons/l10n_fr/__openerp__.py b/addons/l10n_fr/__openerp__.py
index 708f72d2147..faaa963d4f1 100644
--- a/addons/l10n_fr/__openerp__.py
+++ b/addons/l10n_fr/__openerp__.py
@@ -31,7 +31,7 @@
"author" : "OpenERP SA",
"website": "http://www.openerp.com",
"category" : "Localisation/Account Charts",
- "description": """This is the module to manage the accounting chart for France in Open ERP.
+ "description": """This is the module to manage the accounting chart for France in OpenERP.
Credits: Sistheo Zeekom CrysaLEAD
""",
diff --git a/addons/mail_gateway/scripts/openerp_mailgate/openerp_mailgate.py b/addons/mail_gateway/scripts/openerp_mailgate/openerp_mailgate.py
index affd03e03a0..1fed4388e3d 100755
--- a/addons/mail_gateway/scripts/openerp_mailgate/openerp_mailgate.py
+++ b/addons/mail_gateway/scripts/openerp_mailgate/openerp_mailgate.py
@@ -64,15 +64,15 @@ if __name__ == '__main__':
parser = optparse.OptionParser(usage='usage: %prog [options]', version='%prog v1.0')
group = optparse.OptionGroup(parser, "Note",
"This program parse a mail from standard input and communicate "
- "with the Open ERP server for case management in the CRM module.")
+ "with the OpenERP server for case management in the CRM module.")
parser.add_option_group(group)
- parser.add_option("-u", "--user", dest="userid", help="ID of the user in Open ERP", default=1, type='int')
- parser.add_option("-p", "--password", dest="password", help="Password of the user in Open ERP", default='admin')
+ parser.add_option("-u", "--user", dest="userid", help="ID of the user in OpenERP", default=1, type='int')
+ parser.add_option("-p", "--password", dest="password", help="Password of the user in OpenERP", default='admin')
parser.add_option("-o", "--model", dest="model", help="Name or ID of crm model", default="crm.lead")
parser.add_option("-m", "--default", dest="default", help="Default eMail in case of any trouble.", default=None)
parser.add_option("-d", "--dbname", dest="dbname", help="Database name (default: terp)", default='terp')
- parser.add_option("--host", dest="host", help="Hostname of the Open ERP Server", default="localhost")
- parser.add_option("--port", dest="port", help="Port of the Open ERP Server", default="8069")
+ parser.add_option("--host", dest="host", help="Hostname of the OpenERP Server", default="localhost")
+ parser.add_option("--port", dest="port", help="Port of the OpenERP Server", default="8069")
(options, args) = parser.parse_args()
diff --git a/addons/mrp/__openerp__.py b/addons/mrp/__openerp__.py
index b5c72d41f68..cc0694a7098 100644
--- a/addons/mrp/__openerp__.py
+++ b/addons/mrp/__openerp__.py
@@ -28,7 +28,7 @@
"category" : "Generic Modules/Production",
"depends" : ["procurement", "stock", "resource", "purchase", "product","process"],
"description": """
- This is the base module to manage the manufacturing process in Open ERP.
+ This is the base module to manage the manufacturing process in OpenERP.
Features:
* Make to Stock / Make to Order (by line)
diff --git a/addons/mrp/report/price.py b/addons/mrp/report/price.py
index ca8e9b9c0b7..5474646c004 100644
--- a/addons/mrp/report/price.py
+++ b/addons/mrp/report/price.py
@@ -91,7 +91,7 @@ class report_custom(report_rml):
xml += "
" + str(cost_hour) + ''
xml += "
" + str(cost_hour + cost_cycle) + ''
xml += ''
-
+
return xml, total
@@ -105,10 +105,10 @@ class report_custom(report_rml):
60.00mm,60.00mm, 20.00mm, 20.00mm, 20.00mm, 20.00mm
"""
config_stop = """
- Generated by Open ERP
+ Generated by OpenERP
"""
-
+
workcenter_header = """
diff --git a/addons/procurement/procurement.py b/addons/procurement/procurement.py
index 4aad723b2f9..dc072cc520a 100644
--- a/addons/procurement/procurement.py
+++ b/addons/procurement/procurement.py
@@ -72,7 +72,7 @@ class procurement_order(osv.osv):
'name': fields.char('Reason', size=64, required=True, help='Procurement name.'),
'origin': fields.char('Source Document', size=64,
help="Reference of the document that created this Procurement.\n"
- "This is automatically completed by Open ERP."),
+ "This is automatically completed by OpenERP."),
'priority': fields.selection([('0','Not urgent'),('1','Normal'),('2','Urgent'),('3','Very Urgent')], 'Priority', required=True),
'date_planned': fields.datetime('Scheduled date', required=True),
'date_close': fields.datetime('Date Closed'),
@@ -367,13 +367,13 @@ class procurement_order(osv.osv):
if not (procurement.move_id.state in ('done','assigned','cancel')):
ok = ok and self.pool.get('stock.move').action_assign(cr, uid, [id])
cr.execute('select count(id) from stock_warehouse_orderpoint where product_id=%s', (procurement.product_id.id,))
- if not cr.fetchone()[0]:
+ if not cr.fetchone()[0]:
cr.execute('update procurement_order set message=%s where id=%s', (_('Not enough stock and no minimum orderpoint rule defined.'), procurement.id))
message = _('Procurement ') + " '" + procurement.name + "' "+ _("has an exception.") + _('Not enough stock and no minimum orderpoint rule defined.')
self.log(cr, uid, procurement.id, message)
if procurement.state=='exception' and procurement.message=='':
- cr.execute('update procurement_order set message=%s where id=%s', (_('Not enough stock '), procurement.id))
-
+ cr.execute('update procurement_order set message=%s where id=%s', (_('Not enough stock '), procurement.id))
+
return ok
def action_produce_assign_service(self, cr, uid, ids, context={}):
@@ -478,7 +478,7 @@ class stock_warehouse_orderpoint(osv.osv):
"""
_name = "stock.warehouse.orderpoint"
_description = "Minimum Inventory Rule"
-
+
_columns = {
'name': fields.char('Name', size=32, required=True),
'active': fields.boolean('Active', help="If the active field is set to true, it will allow you to hide the orderpoint without removing it."),
@@ -488,10 +488,10 @@ class stock_warehouse_orderpoint(osv.osv):
'product_id': fields.many2one('product.product', 'Product', required=True, ondelete='cascade', domain=[('type','=','product')]),
'product_uom': fields.many2one('product.uom', 'Product UOM', required=True),
'product_min_qty': fields.float('Min Quantity', required=True,
- help="When the virtual stock goes belong the Min Quantity, Open ERP generates "\
+ help="When the virtual stock goes belong the Min Quantity, OpenERP generates "\
"a procurement to bring the virtual stock to the Max Quantity."),
'product_max_qty': fields.float('Max Quantity', required=True,
- help="When the virtual stock goes belong the Max Quantity, Open ERP generates "\
+ help="When the virtual stock goes belong the Max Quantity, OpenERP generates "\
"a procurement to bring the virtual stock to the Max Quantity."),
'qty_multiple': fields.integer('Qty Multiple', required=True,
help="The procurement quantity will by rounded up to this multiple."),
@@ -508,8 +508,8 @@ class stock_warehouse_orderpoint(osv.osv):
}
_sql_constraints = [
('qty_multiple_check', 'CHECK( qty_multiple > 0 )', _('Qty Multiple must be greater than zero.')),
- ]
-
+ ]
+
def onchange_warehouse_id(self, cr, uid, ids, warehouse_id, context={}):
""" Finds location id for changed warehouse.
@param warehouse_id: Changed id of warehouse.
diff --git a/addons/product/__openerp__.py b/addons/product/__openerp__.py
index 15dec4892d1..0a0cfceff20 100644
--- a/addons/product/__openerp__.py
+++ b/addons/product/__openerp__.py
@@ -29,7 +29,7 @@
"init_xml" : [],
"demo_xml" : ["product_demo.xml"],
"description": """
- This is the base module for managing products and pricelists in Open ERP.
+ This is the base module for managing products and pricelists in OpenERP.
Products support variants, different pricing methods, suppliers
information, make to stock/order, different unit of measures,
diff --git a/addons/profile_accounting/profile_accounting.py b/addons/profile_accounting/profile_accounting.py
index b8c3cf7b0fe..d130deb41b4 100644
--- a/addons/profile_accounting/profile_accounting.py
+++ b/addons/profile_accounting/profile_accounting.py
@@ -33,7 +33,7 @@ class profile_accounting_config_install_modules_wizard(osv.osv_memory):
'account_asset':fields.boolean('Asset Management'),
'hr_timesheet_invoice':fields.boolean('Invoice on Analytic Entries'),
'account_budget':fields.boolean('Budgets', help="Helps you to manage financial and analytic budgets."),
- 'board_document':fields.boolean('Document Management',help= "The Document Management System of Open ERP allows you to store, browse, automatically index, search and preview all kind of documents (internal documents, printed reports, calendar system). It opens an FTP access for the users to easily browse association's document."),
+ 'board_document':fields.boolean('Document Management',help= "The Document Management System of OpenERP allows you to store, browse, automatically index, search and preview all kind of documents (internal documents, printed reports, calendar system). It opens an FTP access for the users to easily browse association's document."),
}
profile_accounting_config_install_modules_wizard()
diff --git a/addons/project_scrum/report/sprint_burndown.py b/addons/project_scrum/report/sprint_burndown.py
index 1b4219db3e0..2bbe69be485 100644
--- a/addons/project_scrum/report/sprint_burndown.py
+++ b/addons/project_scrum/report/sprint_burndown.py
@@ -48,7 +48,7 @@ class report_tasks(report_int):
io = StringIO.StringIO()
canv = canvas.init(fname=io, format='pdf')
- canv.set_author("Open ERP")
+ canv.set_author("OpenERP")
cr.execute('select id,date_start,date_stop from project_scrum_sprint where id=%s', (datas['id'],))
for (id,date_start,date_stop) in cr.fetchall():
diff --git a/addons/project_scrum/report/task_burndown.py b/addons/project_scrum/report/task_burndown.py
index 95dbaec656c..50a02792ced 100644
--- a/addons/project_scrum/report/task_burndown.py
+++ b/addons/project_scrum/report/task_burndown.py
@@ -93,7 +93,7 @@ class report_tasks(report_int):
datas = _burndown.compute_burndown(cr, uid, ids, datas['date_start'], datas['date_stop'])
canv = canvas.init(fname=io, format='pdf')
- canv.set_author("Open ERP")
+ canv.set_author("OpenERP")
max_hour = reduce(lambda x,y: max(y[1],x), datas, 0)
diff --git a/addons/project_timesheet/project_timesheet.py b/addons/project_timesheet/project_timesheet.py
index 26368e109c5..46833ba1d4e 100644
--- a/addons/project_timesheet/project_timesheet.py
+++ b/addons/project_timesheet/project_timesheet.py
@@ -203,7 +203,7 @@ class task(osv.osv):
task()
class project_project(osv.osv):
- _inherit = "project.project"
+ _inherit = "project.projesct"
def name_get(self, cr, user, ids, context=None):
if context is None:
diff --git a/addons/sale/sale.py b/addons/sale/sale.py
index bbc5605fda8..c1ea2ea6a8e 100644
--- a/addons/sale/sale.py
+++ b/addons/sale/sale.py
@@ -1165,7 +1165,7 @@ class sale_config_picking_policy(osv.osv_memory):
('one', 'Delivery Order Only'),
('two', 'Picking List & Delivery Order')
], 'Steps To Deliver a Sale Order', required=True,
- help="By default, Open ERP is able to manage complex routing and paths "\
+ help="By default, OpenERP is able to manage complex routing and paths "\
"of products in your warehouse and partner locations. This will configure "\
"the most common and simple methods to deliver products to the customer "\
"in one or two operations by the worker.")
diff --git a/addons/stock/report/stock_by_location.py b/addons/stock/report/stock_by_location.py
index 2b019936100..2dbe03a347e 100644
--- a/addons/stock/report/stock_by_location.py
+++ b/addons/stock/report/stock_by_location.py
@@ -35,7 +35,7 @@ class report_custom(report_rml):
841.8860.00mm,60.00mm,60.00mmStock by location
- Generated by Open ERP
+ Generated by OpenERP
"""
header = """
diff --git a/addons/stock/report/stock_graph.py b/addons/stock/report/stock_graph.py
index bb97119c299..4d4c03fb80c 100644
--- a/addons/stock/report/stock_graph.py
+++ b/addons/stock/report/stock_graph.py
@@ -30,7 +30,7 @@ class stock_graph(object):
def __init__(self, io):
self._datas = {}
self._canvas = canvas.init(fname=io, format='pdf')
- self._canvas.set_author("Open ERP")
+ self._canvas.set_author("OpenERP")
self._names = {}
self.val_min = ''
self.val_max = ''
diff --git a/addons/l10n_chart_uk_minimal/__openerp__.py b/addons/l10n_chart_uk_minimal/__openerp__.py
index 837bf61d07e..67258688f6b 100644
--- a/addons/l10n_chart_uk_minimal/__openerp__.py
+++ b/addons/l10n_chart_uk_minimal/__openerp__.py
@@ -21,10 +21,10 @@
#
# This module provides a minimal UK chart of accounts for building upon further
# Open ERP's default currency and accounts are remapped to this chart
#
# This module works for Open ERP 4.1.0 (and, assumed, onwards).
# This module does not work for Open ERP 4.0.2 and before.
#
# VAT is structured thus:
# - the user company is assumed to be non-VAT exempt (easy to modify, however)
@@ -47,13 +47,13 @@
# - refunds of invoices are deducted from the output category
#
# This forms a basis for accrual tax accounting
# Cash tax accounting can be accommodated with further processing in Open ERP
#
# Status beta 0.92 - tested on Open ERP 4.1.0
# Status beta 0.93 - tested on Open ERP 4.1.0
# - trivial change to depend only on 'account'
# (seemed to be important for importing with no demo data)
# Status 1.0 - tested on Open ERP 4.1.0, 4.0.3
# - COGS account type fixed
#
@@ -62,7 +62,7 @@
'name': 'United Kingdom - minimal',
'version': '1.1',
'category': 'Localisation/Account Charts',
- 'description': """This is the base module to manage the accounting chart for United Kingdom in Open ERP.""",
+ 'description': """This is the base module to manage the accounting chart for United Kingdom in OpenERP.""",
'author': 'Seath Solutions Ltd',
'website': 'http://www.seathsolutions.com',
'depends': ['base', 'account', 'base_iban', 'base_vat', 'account_chart'],
@@ -21,10 +21,10 @@
#
# This module provides a minimal UK chart of accounts for building upon further
-# Open ERP's default currency and accounts are remapped to this chart
+# OpenERP's default currency and accounts are remapped to this chart
#
@@ -21,10 +21,10 @@
#
-# This module works for Open ERP 4.1.0 (and, assumed, onwards).
-# This module does not work for Open ERP 4.0.2 and before.
+# This module works for OpenERP 4.1.0 (and, assumed, onwards).
+# This module does not work for OpenERP 4.0.2 and before.
#
# VAT is structured thus:
@@ -47,13 +47,13 @@
#
# This forms a basis for accrual tax accounting
-# Cash tax accounting can be accommodated with further processing in Open ERP
+# Cash tax accounting can be accommodated with further processing in OpenERP
#
@@ -47,13 +47,13 @@
#
-# Status beta 0.92 - tested on Open ERP 4.1.0
-# Status beta 0.93 - tested on Open ERP 4.1.0
+# Status beta 0.92 - tested on OpenERP 4.1.0
+# Status beta 0.93 - tested on OpenERP 4.1.0
# - trivial change to depend only on 'account'
# (seemed to be important for importing with no demo data)
@@ -47,13 +47,13 @@
# - trivial change to depend only on 'account'
# (seemed to be important for importing with no demo data)
-# Status 1.0 - tested on Open ERP 4.1.0, 4.0.3
+# Status 1.0 - tested on OpenERP 4.1.0, 4.0.3
# - COGS account type fixed
#